@@ -4,7 +4,7 @@
 /****************************************************************************
 ** Meta object code from reading C++ file 'moc-octave-qscintilla.h'
 **
-** Created by: The Qt Meta Object Compiler version 69 (Qt 6.9.1)
+** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
@@ -22,7 +22,7 @@
 #if !defined(Q_MOC_OUTPUT_REVISION)
 #error "The header file 'moc-octave-qscintilla.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 69
-#error "This file was generated using the moc from 6.9.1. It"
+#error "This file was generated using the moc from 6.10.0. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
@@ -55,6 +55,7 @@ template <> constexpr inline auto octave::octave_qscintilla::qt_create_metaobjec
         "status_update",
         "show_doc_signal",
         "show_symbol_tooltip_signal",
+        "QPoint",
         "context_menu_break_condition_signal",
         "context_menu_break_once",
         "ctx_menu_run_finished_signal",
@@ -111,74 +112,74 @@ template <> constexpr inline auto octave::octave_qscintilla::qt_create_metaobjec
         }}),
         // Signal 'show_symbol_tooltip_signal'
         QtMocHelpers::SignalData<void(const QPoint &, const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QPoint, 2 }, { QMetaType::QString, 2 },
+            { 0x80000000 | 13, 2 }, { QMetaType::QString, 2 },
         }}),
         // Signal 'context_menu_break_condition_signal'
-        QtMocHelpers::SignalData<void(int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::Int, 2 },
-        }}),
-        // Signal 'context_menu_break_once'
         QtMocHelpers::SignalData<void(int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
             { QMetaType::Int, 2 },
         }}),
+        // Signal 'context_menu_break_once'
+        QtMocHelpers::SignalData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::Int, 2 },
+        }}),
         // Signal 'ctx_menu_run_finished_signal'
-        QtMocHelpers::SignalData<void(int, QPointer<QTemporaryFile>, QPointer<QTemporaryFile>, bool, bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::Int, 2 }, { 0x80000000 | 16, 2 }, { 0x80000000 | 16, 2 }, { QMetaType::Bool, 2 },
+        QtMocHelpers::SignalData<void(int, QPointer<QTemporaryFile>, QPointer<QTemporaryFile>, bool, bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::Int, 2 }, { 0x80000000 | 17, 2 }, { 0x80000000 | 17, 2 }, { QMetaType::Bool, 2 },
             { QMetaType::Bool, 2 },
         }}),
         // Signal 'focus_console_after_command_signal'
-        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
         // Signal 'interpreter_event'
-        QtMocHelpers::SignalData<void(const fcn_callback &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 19, 20 },
+        QtMocHelpers::SignalData<void(const fcn_callback &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 20, 21 },
         }}),
         // Signal 'interpreter_event'
-        QtMocHelpers::SignalData<void(const meth_callback &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 21, 22 },
+        QtMocHelpers::SignalData<void(const meth_callback &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 22, 23 },
         }}),
         // Slot 'handle_enter_debug_mode'
-        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
-        // Slot 'handle_exit_debug_mode'
         QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
+        // Slot 'handle_exit_debug_mode'
+        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'ctx_menu_run_finished'
-        QtMocHelpers::SlotData<void(int, QPointer<QTemporaryFile>, QPointer<QTemporaryFile>, bool, bool)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Int, 2 }, { 0x80000000 | 16, 2 }, { 0x80000000 | 16, 2 }, { QMetaType::Bool, 2 },
+        QtMocHelpers::SlotData<void(int, QPointer<QTemporaryFile>, QPointer<QTemporaryFile>, bool, bool)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Int, 2 }, { 0x80000000 | 17, 2 }, { 0x80000000 | 17, 2 }, { QMetaType::Bool, 2 },
             { QMetaType::Bool, 2 },
         }}),
         // Slot 'contextmenu_help'
-        QtMocHelpers::SlotData<void(bool)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Bool, 2 },
-        }}),
-        // Slot 'contextmenu_doc'
         QtMocHelpers::SlotData<void(bool)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
             { QMetaType::Bool, 2 },
         }}),
-        // Slot 'contextmenu_help_doc'
+        // Slot 'contextmenu_doc'
         QtMocHelpers::SlotData<void(bool)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
             { QMetaType::Bool, 2 },
         }}),
-        // Slot 'contextmenu_edit'
+        // Slot 'contextmenu_help_doc'
         QtMocHelpers::SlotData<void(bool)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
             { QMetaType::Bool, 2 },
         }}),
-        // Slot 'contextmenu_run'
+        // Slot 'contextmenu_edit'
         QtMocHelpers::SlotData<void(bool)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
             { QMetaType::Bool, 2 },
         }}),
+        // Slot 'contextmenu_run'
+        QtMocHelpers::SlotData<void(bool)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 2 },
+        }}),
         // Slot 'contextmenu_run_temp_error'
-        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'contextmenu_break_condition'
-        QtMocHelpers::SlotData<void(bool)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
+        QtMocHelpers::SlotData<void(bool)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
             { QMetaType::Bool, 2 },
         }}),
         // Slot 'contextmenu_break_once'
-        QtMocHelpers::SlotData<void(const QPoint &)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::QPoint, 2 },
+        QtMocHelpers::SlotData<void(const QPoint &)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { 0x80000000 | 13, 2 },
         }}),
         // Slot 'text_changed'
-        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'cursor_position_changed'
-        QtMocHelpers::SlotData<void(int, int)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
+        QtMocHelpers::SlotData<void(int, int)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
             { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
         }}),
     };
@@ -204,33 +205,33 @@ void octave::octave_qscintilla::qt_static_metacall(QObject *_o, QMetaObject::Cal
     auto *_t = static_cast<octave_qscintilla *>(_o);
     if (_c == QMetaObject::InvokeMetaMethod) {
         switch (_id) {
-        case 0: _t->update_rowcol_indicator_signal((*reinterpret_cast< std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<int>>(_a[2]))); break;
-        case 1: _t->execute_command_in_terminal_signal((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
-        case 2: _t->create_context_menu_signal((*reinterpret_cast< std::add_pointer_t<QMenu*>>(_a[1]))); break;
-        case 3: _t->context_menu_edit_signal((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
-        case 4: _t->qsci_has_focus_signal((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 5: _t->status_update((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[2]))); break;
-        case 6: _t->show_doc_signal((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
-        case 7: _t->show_symbol_tooltip_signal((*reinterpret_cast< std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[2]))); break;
-        case 8: _t->context_menu_break_condition_signal((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
-        case 9: _t->context_menu_break_once((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
-        case 10: _t->ctx_menu_run_finished_signal((*reinterpret_cast< std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QPointer<QTemporaryFile>>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<QPointer<QTemporaryFile>>>(_a[3])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[5]))); break;
+        case 0: _t->update_rowcol_indicator_signal((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
+        case 1: _t->execute_command_in_terminal_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
+        case 2: _t->create_context_menu_signal((*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[1]))); break;
+        case 3: _t->context_menu_edit_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
+        case 4: _t->qsci_has_focus_signal((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 5: _t->status_update((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
+        case 6: _t->show_doc_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
+        case 7: _t->show_symbol_tooltip_signal((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
+        case 8: _t->context_menu_break_condition_signal((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
+        case 9: _t->context_menu_break_once((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
+        case 10: _t->ctx_menu_run_finished_signal((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointer<QTemporaryFile>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPointer<QTemporaryFile>>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
         case 11: _t->focus_console_after_command_signal(); break;
-        case 12: _t->interpreter_event((*reinterpret_cast< std::add_pointer_t<fcn_callback>>(_a[1]))); break;
-        case 13: _t->interpreter_event((*reinterpret_cast< std::add_pointer_t<meth_callback>>(_a[1]))); break;
+        case 12: _t->interpreter_event((*reinterpret_cast<std::add_pointer_t<fcn_callback>>(_a[1]))); break;
+        case 13: _t->interpreter_event((*reinterpret_cast<std::add_pointer_t<meth_callback>>(_a[1]))); break;
         case 14: _t->handle_enter_debug_mode(); break;
         case 15: _t->handle_exit_debug_mode(); break;
-        case 16: _t->ctx_menu_run_finished((*reinterpret_cast< std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QPointer<QTemporaryFile>>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<QPointer<QTemporaryFile>>>(_a[3])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[5]))); break;
-        case 17: _t->contextmenu_help((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 18: _t->contextmenu_doc((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 19: _t->contextmenu_help_doc((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 20: _t->contextmenu_edit((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 21: _t->contextmenu_run((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
+        case 16: _t->ctx_menu_run_finished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointer<QTemporaryFile>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPointer<QTemporaryFile>>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
+        case 17: _t->contextmenu_help((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 18: _t->contextmenu_doc((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 19: _t->contextmenu_help_doc((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 20: _t->contextmenu_edit((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 21: _t->contextmenu_run((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
         case 22: _t->contextmenu_run_temp_error(); break;
-        case 23: _t->contextmenu_break_condition((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 24: _t->contextmenu_break_once((*reinterpret_cast< std::add_pointer_t<QPoint>>(_a[1]))); break;
+        case 23: _t->contextmenu_break_condition((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 24: _t->contextmenu_break_once((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
         case 25: _t->text_changed(); break;
-        case 26: _t->cursor_position_changed((*reinterpret_cast< std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<int>>(_a[2]))); break;
+        case 26: _t->cursor_position_changed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
         default: ;
         }
     }
