@@ -4,7 +4,7 @@
 /****************************************************************************
 ** Meta object code from reading C++ file 'moc-files-dock-widget.h'
 **
-** Created by: The Qt Meta Object Compiler version 69 (Qt 6.9.1)
+** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
@@ -21,7 +21,7 @@
 #if !defined(Q_MOC_OUTPUT_REVISION)
 #error "The header file 'moc-files-dock-widget.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 69
-#error "This file was generated using the moc from 6.9.1. It"
+#error "This file was generated using the moc from 6.10.0. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
@@ -76,6 +76,7 @@ template <> constexpr inline auto octave::files_dock_widget::qt_create_metaobjec
         "save_settings",
         "restore_header_state",
         "headercontextmenu_requested",
+        "QPoint",
         "pos",
         "toggle_header",
         "col",
@@ -171,114 +172,114 @@ template <> constexpr inline auto octave::files_dock_widget::qt_create_metaobjec
         QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'headercontextmenu_requested'
         QtMocHelpers::SlotData<void(const QPoint &)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::QPoint, 35 },
+            { 0x80000000 | 35, 36 },
         }}),
         // Slot 'toggle_header'
-        QtMocHelpers::SlotData<void(int)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Int, 37 },
+        QtMocHelpers::SlotData<void(int)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Int, 38 },
         }}),
         // Slot 'contextmenu_requested'
-        QtMocHelpers::SlotData<void(const QPoint &)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::QPoint, 35 },
+        QtMocHelpers::SlotData<void(const QPoint &)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { 0x80000000 | 35, 36 },
         }}),
         // Slot 'contextmenu_open'
-        QtMocHelpers::SlotData<void(bool)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Bool, 2 },
-        }}),
-        // Slot 'contextmenu_open_in_editor'
         QtMocHelpers::SlotData<void(bool)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
             { QMetaType::Bool, 2 },
         }}),
-        // Slot 'contextmenu_open_in_app'
+        // Slot 'contextmenu_open_in_editor'
         QtMocHelpers::SlotData<void(bool)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
             { QMetaType::Bool, 2 },
         }}),
-        // Slot 'contextmenu_copy_selection'
+        // Slot 'contextmenu_open_in_app'
         QtMocHelpers::SlotData<void(bool)>(42, 2, QMC::AccessPrivate, QMetaType::Void, {{
             { QMetaType::Bool, 2 },
         }}),
-        // Slot 'contextmenu_run'
+        // Slot 'contextmenu_copy_selection'
         QtMocHelpers::SlotData<void(bool)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
             { QMetaType::Bool, 2 },
         }}),
-        // Slot 'contextmenu_load'
+        // Slot 'contextmenu_run'
         QtMocHelpers::SlotData<void(bool)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
             { QMetaType::Bool, 2 },
         }}),
-        // Slot 'contextmenu_rename'
+        // Slot 'contextmenu_load'
         QtMocHelpers::SlotData<void(bool)>(45, 2, QMC::AccessPrivate, QMetaType::Void, {{
             { QMetaType::Bool, 2 },
         }}),
-        // Slot 'contextmenu_delete'
+        // Slot 'contextmenu_rename'
         QtMocHelpers::SlotData<void(bool)>(46, 2, QMC::AccessPrivate, QMetaType::Void, {{
             { QMetaType::Bool, 2 },
         }}),
-        // Slot 'contextmenu_newfile'
+        // Slot 'contextmenu_delete'
         QtMocHelpers::SlotData<void(bool)>(47, 2, QMC::AccessPrivate, QMetaType::Void, {{
             { QMetaType::Bool, 2 },
         }}),
-        // Slot 'contextmenu_newdir'
+        // Slot 'contextmenu_newfile'
         QtMocHelpers::SlotData<void(bool)>(48, 2, QMC::AccessPrivate, QMetaType::Void, {{
             { QMetaType::Bool, 2 },
         }}),
-        // Slot 'contextmenu_setcurrentdir'
+        // Slot 'contextmenu_newdir'
         QtMocHelpers::SlotData<void(bool)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
             { QMetaType::Bool, 2 },
         }}),
+        // Slot 'contextmenu_setcurrentdir'
+        QtMocHelpers::SlotData<void(bool)>(50, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 2 },
+        }}),
         // Slot 'contextmenu_add_to_path'
-        QtMocHelpers::SlotData<void(bool, bool, bool)>(50, 2, QMC::AccessPrivate, QMetaType::Void, {{
+        QtMocHelpers::SlotData<void(bool, bool, bool)>(51, 2, QMC::AccessPrivate, QMetaType::Void, {{
             { QMetaType::Bool, 2 }, { QMetaType::Bool, 20 }, { QMetaType::Bool, 21 },
         }}),
         // Slot 'contextmenu_add_to_path'
-        QtMocHelpers::SlotData<void(bool, bool)>(50, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
+        QtMocHelpers::SlotData<void(bool, bool)>(51, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
             { QMetaType::Bool, 2 }, { QMetaType::Bool, 20 },
         }}),
         // Slot 'contextmenu_add_to_path'
-        QtMocHelpers::SlotData<void(bool)>(50, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
+        QtMocHelpers::SlotData<void(bool)>(51, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
             { QMetaType::Bool, 2 },
         }}),
         // Slot 'contextmenu_add_to_path_subdirs'
-        QtMocHelpers::SlotData<void(bool)>(51, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Bool, 2 },
-        }}),
-        // Slot 'contextmenu_rm_from_path'
         QtMocHelpers::SlotData<void(bool)>(52, 2, QMC::AccessPrivate, QMetaType::Void, {{
             { QMetaType::Bool, 2 },
         }}),
-        // Slot 'contextmenu_rm_from_path_subdirs'
+        // Slot 'contextmenu_rm_from_path'
         QtMocHelpers::SlotData<void(bool)>(53, 2, QMC::AccessPrivate, QMetaType::Void, {{
             { QMetaType::Bool, 2 },
         }}),
-        // Slot 'contextmenu_findfiles'
+        // Slot 'contextmenu_rm_from_path_subdirs'
         QtMocHelpers::SlotData<void(bool)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
             { QMetaType::Bool, 2 },
         }}),
-        // Slot 'popdownmenu_newfile'
+        // Slot 'contextmenu_findfiles'
         QtMocHelpers::SlotData<void(bool)>(55, 2, QMC::AccessPrivate, QMetaType::Void, {{
             { QMetaType::Bool, 2 },
         }}),
-        // Slot 'popdownmenu_newdir'
+        // Slot 'popdownmenu_newfile'
         QtMocHelpers::SlotData<void(bool)>(56, 2, QMC::AccessPrivate, QMetaType::Void, {{
             { QMetaType::Bool, 2 },
         }}),
-        // Slot 'popdownmenu_search_dir'
+        // Slot 'popdownmenu_newdir'
         QtMocHelpers::SlotData<void(bool)>(57, 2, QMC::AccessPrivate, QMetaType::Void, {{
             { QMetaType::Bool, 2 },
         }}),
-        // Slot 'popdownmenu_findfiles'
+        // Slot 'popdownmenu_search_dir'
         QtMocHelpers::SlotData<void(bool)>(58, 2, QMC::AccessPrivate, QMetaType::Void, {{
             { QMetaType::Bool, 2 },
         }}),
-        // Slot 'popdownmenu_home'
+        // Slot 'popdownmenu_findfiles'
         QtMocHelpers::SlotData<void(bool)>(59, 2, QMC::AccessPrivate, QMetaType::Void, {{
             { QMetaType::Bool, 2 },
         }}),
+        // Slot 'popdownmenu_home'
+        QtMocHelpers::SlotData<void(bool)>(60, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 2 },
+        }}),
         // Slot 'copyClipboard'
-        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'pasteClipboard'
         QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'selectAll'
+        // Slot 'pasteClipboard'
         QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'selectAll'
+        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPrivate, QMetaType::Void),
     };
     QtMocHelpers::UintData qt_properties {
     };
@@ -302,51 +303,51 @@ void octave::files_dock_widget::qt_static_metacall(QObject *_o, QMetaObject::Cal
     auto *_t = static_cast<files_dock_widget *>(_o);
     if (_c == QMetaObject::InvokeMetaMethod) {
         switch (_id) {
-        case 0: _t->open_file((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
-        case 1: _t->displayed_directory_changed((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
-        case 2: _t->load_file_signal((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
-        case 3: _t->open_any_signal((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
-        case 4: _t->run_file_signal((*reinterpret_cast< std::add_pointer_t<QFileInfo>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<int>>(_a[2]))); break;
-        case 5: _t->find_files_signal((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
-        case 6: _t->file_remove_signal((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[2]))); break;
-        case 7: _t->file_renamed_signal((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 8: _t->modify_path_signal((*reinterpret_cast< std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[3]))); break;
-        case 9: _t->item_double_clicked((*reinterpret_cast< std::add_pointer_t<QModelIndex>>(_a[1]))); break;
+        case 0: _t->open_file((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
+        case 1: _t->displayed_directory_changed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
+        case 2: _t->load_file_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
+        case 3: _t->open_any_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
+        case 4: _t->run_file_signal((*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
+        case 5: _t->find_files_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
+        case 6: _t->file_remove_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
+        case 7: _t->file_renamed_signal((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 8: _t->modify_path_signal((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
+        case 9: _t->item_double_clicked((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
         case 10: _t->change_directory_up(); break;
         case 11: _t->do_sync_octave_directory(); break;
         case 12: _t->do_sync_browser_directory(); break;
-        case 13: _t->set_current_directory((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
+        case 13: _t->set_current_directory((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
         case 14: _t->accept_directory_line_edit(); break;
-        case 15: _t->update_octave_directory((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
+        case 15: _t->update_octave_directory((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
         case 16: _t->notice_settings(); break;
         case 17: _t->save_settings(); break;
         case 18: _t->restore_header_state(); break;
-        case 19: _t->headercontextmenu_requested((*reinterpret_cast< std::add_pointer_t<QPoint>>(_a[1]))); break;
-        case 20: _t->toggle_header((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
-        case 21: _t->contextmenu_requested((*reinterpret_cast< std::add_pointer_t<QPoint>>(_a[1]))); break;
-        case 22: _t->contextmenu_open((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 23: _t->contextmenu_open_in_editor((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 24: _t->contextmenu_open_in_app((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 25: _t->contextmenu_copy_selection((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 26: _t->contextmenu_run((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 27: _t->contextmenu_load((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 28: _t->contextmenu_rename((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 29: _t->contextmenu_delete((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 30: _t->contextmenu_newfile((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 31: _t->contextmenu_newdir((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 32: _t->contextmenu_setcurrentdir((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 33: _t->contextmenu_add_to_path((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[3]))); break;
-        case 34: _t->contextmenu_add_to_path((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[2]))); break;
-        case 35: _t->contextmenu_add_to_path((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 36: _t->contextmenu_add_to_path_subdirs((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 37: _t->contextmenu_rm_from_path((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 38: _t->contextmenu_rm_from_path_subdirs((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 39: _t->contextmenu_findfiles((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 40: _t->popdownmenu_newfile((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 41: _t->popdownmenu_newdir((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 42: _t->popdownmenu_search_dir((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 43: _t->popdownmenu_findfiles((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 44: _t->popdownmenu_home((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
+        case 19: _t->headercontextmenu_requested((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
+        case 20: _t->toggle_header((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
+        case 21: _t->contextmenu_requested((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
+        case 22: _t->contextmenu_open((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 23: _t->contextmenu_open_in_editor((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 24: _t->contextmenu_open_in_app((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 25: _t->contextmenu_copy_selection((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 26: _t->contextmenu_run((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 27: _t->contextmenu_load((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 28: _t->contextmenu_rename((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 29: _t->contextmenu_delete((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 30: _t->contextmenu_newfile((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 31: _t->contextmenu_newdir((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 32: _t->contextmenu_setcurrentdir((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 33: _t->contextmenu_add_to_path((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
+        case 34: _t->contextmenu_add_to_path((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
+        case 35: _t->contextmenu_add_to_path((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 36: _t->contextmenu_add_to_path_subdirs((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 37: _t->contextmenu_rm_from_path((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 38: _t->contextmenu_rm_from_path_subdirs((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 39: _t->contextmenu_findfiles((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 40: _t->popdownmenu_newfile((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 41: _t->popdownmenu_newdir((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 42: _t->popdownmenu_search_dir((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 43: _t->popdownmenu_findfiles((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 44: _t->popdownmenu_home((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
         case 45: _t->copyClipboard(); break;
         case 46: _t->pasteClipboard(); break;
         case 47: _t->selectAll(); break;
