@@ -4,7 +4,7 @@
 /****************************************************************************
 ** Meta object code from reading C++ file 'moc-variable-editor.h'
 **
-** Created by: The Qt Meta Object Compiler version 69 (Qt 6.9.1)
+** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
@@ -21,7 +21,7 @@
 #if !defined(Q_MOC_OUTPUT_REVISION)
 #error "The header file 'moc-variable-editor.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 69
-#error "This file was generated using the moc from 6.9.1. It"
+#error "This file was generated using the moc from 6.10.0. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
@@ -113,13 +113,13 @@ void octave::variable_dock_widget::qt_static_metacall(QObject *_o, QMetaObject::
     auto *_t = static_cast<variable_dock_widget *>(_o);
     if (_c == QMetaObject::InvokeMetaMethod) {
         switch (_id) {
-        case 0: _t->variable_focused_signal((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
+        case 0: _t->variable_focused_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
         case 1: _t->queue_unfloat_float(); break;
         case 2: _t->queue_float(); break;
-        case 3: _t->handle_focus_change((*reinterpret_cast< std::add_pointer_t<QWidget*>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QWidget*>>(_a[2]))); break;
-        case 4: _t->change_floating((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 5: _t->change_existence((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
-        case 6: _t->toplevel_change((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
+        case 3: _t->handle_focus_change((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[2]))); break;
+        case 4: _t->change_floating((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 5: _t->change_existence((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 6: _t->toplevel_change((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
         case 7: _t->change_fullscreen(); break;
         case 8: _t->unfloat_float(); break;
         case 9: _t->refloat(); break;
@@ -269,15 +269,15 @@ void octave::variable_editor_stack::qt_static_metacall(QObject *_o, QMetaObject:
     auto *_t = static_cast<variable_editor_stack *>(_o);
     if (_c == QMetaObject::InvokeMetaMethod) {
         switch (_id) {
-        case 0: _t->edit_variable_signal((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<octave_value>>(_a[2]))); break;
-        case 1: _t->do_save_signal((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[2]))); break;
-        case 2: _t->interpreter_event((*reinterpret_cast< std::add_pointer_t<fcn_callback>>(_a[1]))); break;
-        case 3: _t->interpreter_event((*reinterpret_cast< std::add_pointer_t<meth_callback>>(_a[1]))); break;
-        case 4: _t->set_editable((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
+        case 0: _t->edit_variable_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<octave_value>>(_a[2]))); break;
+        case 1: _t->do_save_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
+        case 2: _t->interpreter_event((*reinterpret_cast<std::add_pointer_t<fcn_callback>>(_a[1]))); break;
+        case 3: _t->interpreter_event((*reinterpret_cast<std::add_pointer_t<meth_callback>>(_a[1]))); break;
+        case 4: _t->set_editable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
         case 5: _t->levelUp(); break;
-        case 6: _t->save((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
+        case 6: _t->save((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
         case 7: _t->save(); break;
-        case 8: _t->do_save((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[2]))); break;
+        case 8: _t->do_save((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
         default: ;
         }
     }
@@ -376,6 +376,7 @@ template <> constexpr inline auto octave::variable_editor_view::qt_create_metaob
         "action",
         "handle_vertical_scroll_action",
         "createContextMenu",
+        "QPoint",
         "pt",
         "createColumnMenu",
         "createRowMenu",
@@ -417,18 +418,18 @@ template <> constexpr inline auto octave::variable_editor_view::qt_create_metaob
         }}),
         // Slot 'createContextMenu'
         QtMocHelpers::SlotData<void(const QPoint &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QPoint, 21 },
+            { 0x80000000 | 21, 22 },
         }}),
         // Slot 'createColumnMenu'
-        QtMocHelpers::SlotData<void(const QPoint &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QPoint, 21 },
+        QtMocHelpers::SlotData<void(const QPoint &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 21, 22 },
         }}),
         // Slot 'createRowMenu'
-        QtMocHelpers::SlotData<void(const QPoint &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QPoint, 21 },
+        QtMocHelpers::SlotData<void(const QPoint &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 21, 22 },
         }}),
         // Slot 'selected_command_requested'
-        QtMocHelpers::SlotData<void(const QString &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
+        QtMocHelpers::SlotData<void(const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
             { QMetaType::QString, 3 },
         }}),
     };
@@ -454,23 +455,23 @@ void octave::variable_editor_view::qt_static_metacall(QObject *_o, QMetaObject::
     auto *_t = static_cast<variable_editor_view *>(_o);
     if (_c == QMetaObject::InvokeMetaMethod) {
         switch (_id) {
-        case 0: _t->command_signal((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
-        case 1: _t->add_edit_actions_signal((*reinterpret_cast< std::add_pointer_t<QMenu*>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QString>>(_a[2]))); break;
+        case 0: _t->command_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
+        case 1: _t->add_edit_actions_signal((*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
         case 2: _t->createVariable(); break;
         case 3: _t->transposeContent(); break;
         case 4: { QList<int> _r = _t->range_selected();
-            if (_a[0]) *reinterpret_cast< QList<int>*>(_a[0]) = std::move(_r); }  break;
+            if (_a[0]) *reinterpret_cast<QList<int>*>(_a[0]) = std::move(_r); }  break;
         case 5: _t->delete_selected(); break;
         case 6: _t->clearContent(); break;
         case 7: _t->cutClipboard(); break;
         case 8: _t->copyClipboard(); break;
         case 9: _t->pasteClipboard(); break;
-        case 10: _t->handle_horizontal_scroll_action((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
-        case 11: _t->handle_vertical_scroll_action((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
-        case 12: _t->createContextMenu((*reinterpret_cast< std::add_pointer_t<QPoint>>(_a[1]))); break;
-        case 13: _t->createColumnMenu((*reinterpret_cast< std::add_pointer_t<QPoint>>(_a[1]))); break;
-        case 14: _t->createRowMenu((*reinterpret_cast< std::add_pointer_t<QPoint>>(_a[1]))); break;
-        case 15: _t->selected_command_requested((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
+        case 10: _t->handle_horizontal_scroll_action((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
+        case 11: _t->handle_vertical_scroll_action((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
+        case 12: _t->createContextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
+        case 13: _t->createColumnMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
+        case 14: _t->createRowMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
+        case 15: _t->selected_command_requested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
         default: ;
         }
     }
@@ -930,7 +931,7 @@ void octave::variable_editor::qt_static_metacall(QObject *_o, QMetaObject::Call
         switch (_id) {
         case 0: _t->updated(); break;
         case 1: _t->finished(); break;
-        case 2: _t->command_signal((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
+        case 2: _t->command_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
         case 3: _t->refresh_signal(); break;
         case 4: _t->clear_content_signal(); break;
         case 5: _t->copy_clipboard_signal(); break;
@@ -938,16 +939,16 @@ void octave::variable_editor::qt_static_metacall(QObject *_o, QMetaObject::Call
         case 7: _t->level_up_signal(); break;
         case 8: _t->save_signal(); break;
         case 9: _t->delete_selected_signal(); break;
-        case 10: _t->interpreter_event((*reinterpret_cast< std::add_pointer_t<fcn_callback>>(_a[1]))); break;
-        case 11: _t->interpreter_event((*reinterpret_cast< std::add_pointer_t<meth_callback>>(_a[1]))); break;
-        case 12: _t->callUpdate((*reinterpret_cast< std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QModelIndex>>(_a[2]))); break;
+        case 10: _t->interpreter_event((*reinterpret_cast<std::add_pointer_t<fcn_callback>>(_a[1]))); break;
+        case 11: _t->interpreter_event((*reinterpret_cast<std::add_pointer_t<meth_callback>>(_a[1]))); break;
+        case 12: _t->callUpdate((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
         case 13: _t->notice_settings(); break;
-        case 14: _t->edit_variable((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<octave_value>>(_a[2]))); break;
-        case 15: _t->variable_destroyed((*reinterpret_cast< std::add_pointer_t<QObject*>>(_a[1]))); break;
-        case 16: _t->variable_focused((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
+        case 14: _t->edit_variable((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<octave_value>>(_a[2]))); break;
+        case 15: _t->variable_destroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
+        case 16: _t->variable_focused((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
         case 17: _t->record_hovered_focus_variable(); break;
         case 18: _t->restore_hovered_focus_variable(); break;
-        case 19: _t->closeEvent((*reinterpret_cast< std::add_pointer_t<QCloseEvent*>>(_a[1]))); break;
+        case 19: _t->closeEvent((*reinterpret_cast<std::add_pointer_t<QCloseEvent*>>(_a[1]))); break;
         case 20: _t->save(); break;
         case 21: _t->cutClipboard(); break;
         case 22: _t->copyClipboard(); break;
